vlog

package
v0.0.0-...-dbf8b16 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2025 License: BSD-3-Clause Imports: 3 Imported by: 0

Documentation

Overview

Package vlog writes messages to a logger attached to a context.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Log

func Log(ctx context.Context, args ...any)

Log writes args to the log.Logger previously attached to ctx. If no logger is attached, writes nothing.

func Logf

func Logf(ctx context.Context, format string, args ...any)

Logf is like Log but uses fmt.Sprintf.

func LoggerContext

func LoggerContext(ctx context.Context, lg *log.Logger) context.Context

LoggerContext attaches lg to a new context derived from ctx. The returned context can later be passed to Log or Logf.

Types

This section is empty.

Jump to